@@ -5,7 +5,7 @@
 #' download the data and 2) saves the downloaded raster on the hard drive (so
 #' that you don't have to keep downloading the same file over and over again).
 #' The file saved on the disk is a *.tif file which you can directly read using
-#' the function [raster::raster].
+#' the function [terra::rast].
 #'
 #' By default (and to keep with the spirit of the former implementations of
 #' `getelev` in IsoriX, which did not rely on [elevatr::elevatr]), an
@@ -53,8 +53,7 @@
 #' @examples
 #' 
 #' ## To download the high resolution
-#' ## raster in your current working
-#' ## directory, just type:
+#' ## raster at the default location, just type:
 #' ## getelev()
 #' 
 #' @export
@@ -70,8 +69,13 @@ getelev <- function(file = "~/elevation_world_z5.tif",
                     Ncpu = getOption_IsoriX("Ncpu"),
                     verbose = interactive(),
                     ...
-                    ) {
-
+) {
+  
+  ## Checking that elevatr is installed
+  if (!requireNamespace("elevatr", quietly = TRUE)) {
+    stop("You must install the package elevatr for this function to run: `install.packages('elevatr')`")
+  }
+  
   ## Turning path into canonical form
   ## (this avoids the problem of using the wrong slashes and so on)
   file <- normalizePath(file, mustWork = FALSE)
@@ -115,10 +119,10 @@ getelev <- function(file = "~/elevation_world_z5.tif",
     )
     )
   } else {
-  
+    
     if (verbose) print("Downloading and formating the elevation raster... (be patient)")
-    elev <- elevatr::get_elev_raster(location = data.frame(long = c(long_min, long_max),
-                                                           lat = c(lat_min, lat_max)),
+    elev <- elevatr::get_elev_raster(locations = data.frame(x = c(long_min, long_max),
+                                                            y = c(lat_min, lat_max)),
                                      z = z,
                                      prj = "+proj=longlat +datum=WGS84 +no_defs",
                                      clip = "bbox",
@@ -128,12 +132,12 @@ getelev <- function(file = "~/elevation_world_z5.tif",
                                      ...)
     
     if (verbose) print("Writing the elevation raster on the disk...")
-    raster::writeRaster(elev, filename = file, overwrite = overwrite)
+    terra::writeRaster(elev, filename = file, overwrite = overwrite)
     if (verbose) print("Done.")
   }
   
   message("you can load your elevation raster as follows:")
-  message(paste0("elev_raster <- raster::raster('", file, "')"))
+  message(paste0("elev_raster <- terra::rast('", file, "')"))
   
   return(invisible(file))
 }
@@ -159,13 +163,16 @@ getelev <- function(file = "~/elevation_world_z5.tif",
 #' 
 #' @inheritParams getelev
 #' @param path A *string* indicating where to store the file on the hard
-#'   drive (without the file name!)
+#'   drive (without the file name!). Default = current directory.
 #' @param verbose A *logical* indicating whether information about the
 #'   progress of the procedure should be displayed or not while the function is
 #'   running. By default verbose is `TRUE` if users use an interactive R
 #'   session and `FALSE` otherwise. If a *numeric* is provided instead,
 #'   additional information about the download will be provided if the number is
 #'   greater than 1.
+#'   
+#' @return This function returns the path of the folder where the files have
+#'   been stored
 #'
 #' @source \url{https://worldclim.org/data/worldclim21.html}
 #' @examples
@@ -179,7 +186,25 @@ getelev <- function(file = "~/elevation_world_z5.tif",
 getprecip <- function(path = NULL,
                       overwrite = FALSE,
                       verbose = interactive()
-                      ) {
+) {
+  
+  ## check options
+  old_opts <- options()
+  if (options()$timeout == 60) {
+    options(timeout = 600)
+    message("You were using R default settings of a maximum of 60s per download, this is unsufficient for downloading the large file. IsoriX temporarily increased this limit to 600s. If this is not sufficient, please call `options(timeout = XX)` with XX the number of seconds you want to allow R waiting for the download to be completed before crashing. After this, rerun `getprecip()`.")
+  } else if (options()$timeout < 600) {
+    message("You are using a custom value of timeout lower than 600s. This could be unsufficient for downloading the large file. If the download crashes as a result, please call `options(timeout = XX)` with XX the number of seconds you want to allow R waiting for the download to be completed before crashing. After this, rerun `getprecip()`.")
+  }
+  on.exit(options(old_opts))
+  
+  ## Use current directory if path is missing
+  if (is.null(path)) {
+    path <- getwd()
+  }
+  
+  ## Normalise path the remove last slash
+  path <- base::normalizePath(path, mustWork = FALSE)
   
   ## Define web address and file name
   address_precip <- "https://biogeo.ucdavis.edu/data/worldclim/v2.1/base/wc2.1_30s_prec.zip"
@@ -196,13 +221,13 @@ getprecip <- function(path = NULL,
                               overwrite = overwrite,
                               md5sum = md5sum_precip,
                               verbose = verbose
-                              )
+  )
   
   ## Unzip the file
   if (verbose > 0) {
     print("unzipping in progress...", quote = FALSE)
   }
-  outpath <- paste0(path, "wc2.1_30s_prec")
+  outpath <- paste0(path, "/wc2.1_30s_prec")
   utils::unzip(path_to_zip, exdir = outpath)
   
   if (verbose > 0) {
@@ -210,7 +235,7 @@ getprecip <- function(path = NULL,
     print(paste("The files can be found in the folder", outpath), quote = FALSE)
   }
   
-  return(invisible(NULL))
+  return(invisible(outpath))
 }
 
 
@@ -249,7 +274,7 @@ getprecip <- function(path = NULL,
 #' 
 downloadfile <- function(address = NULL, filename = NULL, path = NULL,
                          overwrite = FALSE, md5sum = NULL, verbose = interactive()
-                         ) {
+) {
   
   if (verbose > 0) {
     print(paste("the function attempts to download", filename, "from internet"), quote = FALSE)
@@ -271,7 +296,7 @@ downloadfile <- function(address = NULL, filename = NULL, path = NULL,
   ## Create directory if missing
   if (!dir.exists(path)) {
     if (verbose > 0) {
-     print("(the folder you specified does not exist and will therefore be created)", quote = FALSE)
+      print("(the folder you specified does not exist and will therefore be created)", quote = FALSE)
     }
     dir.create(path, recursive = TRUE)
   }
@@ -281,10 +306,11 @@ downloadfile <- function(address = NULL, filename = NULL, path = NULL,
   if (file.exists(complete_path) & !overwrite) {
     message(paste("the file", filename, "is already present in", path,
                   "so it won't be downloaded again unless you set the argument overwrite to TRUE"
-                  )
-            )
+    )
+    )
   } else {
-    utils::download.file(address, destfile = complete_path, mode = "wb")
+    time <- system.time(utils::download.file(address, destfile = complete_path, mode = "wb"))
+    message(paste0("The download lasted ", time[["elapsed"]], "s"))
   }
   
   ## Checking MD5sum
