@@ -1,7 +1,7 @@
 #' Plotting functions for IsoriX
 #'
 #' These functions plot objects created by IsoriX (with the exception of plot
-#' method for RasterLayer created using [raster].
+#' method for SpatRaster created using [terra].
 #'
 #'
 #' **General**
@@ -16,7 +16,7 @@
 #' When called upon an object of class *ISOSCAPE*, the plot function draws a
 #' fine-tuned plot of the isoscape.
 #'
-#' When called upon an object of class *RasterLayer*, the plot function displays
+#' When called upon an object of class *SpatRaster*, the plot function displays
 #' the raster (just for checking things fast and dirty). In this case, the
 #' function is a simple shortcut to [rasterVis::levelplot].
 #'
@@ -67,9 +67,9 @@
 #' objects as in traditional R plotting functions (see [par] for details). The
 #' element `draw` should be a *logical* that indicates whether the layer must be
 #' created or not. The argument `borders` (within the list borders) expects an
-#' object of the class *SpatialPolygons* such as the object [CountryBorders]
+#' object of the class *SpatVector*, such as the object [CountryBorders]
 #' provided with this package. The argument `mask` (within the list mask)
-#' expects an object of the class *SpatialPolygons* such as the object
+#' also expects an object of the class *SpatVector*, such as the object
 #' [OceanMask] provided with this package (see examples).
 #'
 #' The argument `palette` is used to define how to colour the isoscape and
@@ -77,7 +77,7 @@
 #' z-scale that shares a given colour; `range` can be used to constrain the
 #' minimum and/or maximum values to be drawn (e.g. range = c(0, 1)) (this latter
 #' argument is useful if one wants to create several plots with the same
-#' z-scale); `n_labels` allows for the user to approximatively define the
+#' z-scale); `n_labels` allows for the user to approximately define the
 #' maximum number of numbers plotted on the z-scale; `digits` defines the number
 #' of digits displayed for the numbers used as labels; and `fn` is used to
 #' specify the function that is used to sample the colours. If `fn` is NULL
@@ -98,9 +98,9 @@
 #'
 #' @name plots
 #' @aliases plot.ISOFIT plot.ISOSCAPE plot.CALIBFIT plot.ISOFIND
-#'   plot.RasterLayer plot
+#'   plot.SpatRaster
 #' @param x The return object of a call to [isofit], [isoscape], [calibfit],
-#'   [isofind], or [raster::raster]]
+#'   [isofind], or [terra::rast]]
 #' @param cex_scale A *numeric* giving a scaling factor for the points in
 #'   the plots
 #' @param which A *string* indicating the name of the raster to be plotted
@@ -116,7 +116,7 @@
 #' @param calibs A *list* containing information for the display of the
 #'   location of the calibration sampling location (see details)
 #' @param assigns A *list* containing information for the display of the
-#'   location of the assingment sampling location (see details)
+#'   location of the assignment sampling location (see details)
 #' @param borders A *list* containing information for the display of borders
 #'   (e.g. country borders) (see details)
 #' @param mask A *list* containing information for the display of a mask
@@ -130,7 +130,8 @@
 #' @param sphere A *list* containing information whether the raster should
 #'   be returned as a rotating sphere and if the image created during the
 #'   process should be saved in your current working directory. The default
-#'   settings are FALSE.
+#'   settings are FALSE and TRUE, respectively.
+#'   
 #' @param xlab A *string* the x-axis label in plot.CALIBFIT
 #' @param ylab A *string* the y-axis label in plot.CALIBFIT
 #' @param xlim A range defining the extreme coordinates for the the x-axis in
@@ -150,7 +151,7 @@
 #'   a *string* or *integer* indicating the colour for plotting the
 #'   confidence interval
 #' @param ... Additional arguments (only in use in plot.CALIBFIT and
-#'   plot.RasterLayer)
+#'   plot.SpatRaster)
 #'
 #' @seealso [isofit] for the function fitting the isoscape
 #'
@@ -166,7 +167,8 @@
 NULL
 
 #' @rdname plots
-#' @export
+#' @method plot ISOSCAPE
+#' @exportS3Method plot ISOSCAPE
 plot.ISOSCAPE <- function(x,
                           which   = "mean",
                           y_title  = list(which = TRUE, title = bquote(delta**2*H)), ## bquote(italic("\u03B4")**2*H[p]) does not work on all system...
@@ -175,7 +177,7 @@ plot.ISOSCAPE <- function(x,
                           mask    = list(mask = NA, lwd = 0, col = "black", fill = "black"),
                           palette = list(step = NA, range = c(NA, NA), n_labels = 11, digits = 2, fn = NA),
                           plot    = TRUE,
-                          sphere  = list(build = FALSE, keep_image = FALSE),
+                          sphere  = list(build = FALSE, keep_image = TRUE),
                           ... ## we cannot remove the dots because of the S3 export...
                           ) {
     if (!inherits(x, "ISOSCAPE")) {
@@ -196,16 +198,12 @@ plot.ISOSCAPE <- function(x,
 
     ## importing country borders if missing
     if (!is.null(borders$borders) && is.na(borders$borders)) {
-      CountryBorders <- NULL
-      utils::data("CountryBorders", envir = environment(), package = "IsoriX")
-      borders$borders <- CountryBorders
+      borders$borders <- terra::readRDS(system.file("extdata/CountryBorders.rds", package = "IsoriX"))
     }
 
     ## importing ocean if missing
-    if (!is.null(mask$mask) && !inherits(mask$mask, "SpatialPolygons") && is.na(mask$mask)) {
-      OceanMask <- NULL
-      utils::data("OceanMask", envir = environment(), package = "IsoriX")
-      mask$mask <- OceanMask
+    if (!is.null(mask$mask) && !inherits(mask$mask, "SpatVector") && is.na(mask$mask)) {
+      mask$mask <- terra::readRDS(system.file("extdata/OceanMask.rds", package = "IsoriX"))
     }
 
     if (simu) {
@@ -224,12 +222,12 @@ plot.ISOSCAPE <- function(x,
     }
 
     ## compute the colors
-    colours <- .cut_and_color(var     = x$isoscape[[which]], #@data@values,
-                           step     = palette$step,
-                           range    = palette$range,
-                           palette  = palette$fn,
-                           n_labels = palette$n_labels,
-                           digits   = palette$digits)
+    colours <- .cut_and_color(var      = x$isoscape[[which]], #@data@values,
+                              step     = palette$step,
+                              range    = palette$range,
+                              palette  = palette$fn,
+                              n_labels = palette$n_labels,
+                              digits   = palette$digits)
 
     ## define y title
     Title <- ""
@@ -277,8 +275,12 @@ plot.ISOSCAPE <- function(x,
     if (sphere$build) {
       .build_sphere(x$isoscape[[which]], colours = colours, decor = decor)
       if (!sphere$keep_image) {
-        file.remove("IsoriX_world_image.png")
+        message(paste("IsoriX no longer delete the image used to build the sphere since it prevents rgl to work on some system. \n",
+                "You can always delete manually the file created which is stored here: \n",
+                normalizePath(file.path("IsoriX_world_image.png"))))
+        #file.remove("IsoriX_world_image.png")
       }
+      message("If you do not see the sphere, run rgl::rglwidget()")
     }
     
     return(invisible(complete_map))
@@ -297,10 +299,9 @@ plot.ISOSCAPE <- function(x,
     print("(this may take a few seconds)", quote = FALSE)
   }
   ### check extent of the raster and extend to world if necessary
-  world_raster <- raster::raster()
-  raster::extent(world_raster) <- c(-180, 180, -90, 90)
-  if (raster::extent(x) < raster::extent(world_raster)) {
-    x <- raster::extend(x, raster::extent(world_raster))
+  world_raster <- terra::rast()
+  if (terra::ext(x) < terra::ext(world_raster)) {
+    terra::ext(x) <- terra::ext(world_raster)
   }
   p <- rasterVis::levelplot(x,
                             col.regions = colours$all_cols,
@@ -319,7 +320,7 @@ plot.ISOSCAPE <- function(x,
   do.call(p$panel, pargs)
   grDevices::dev.off()
   
-  if (length(rgl::rgl.dev.list()) > 0) rgl::rgl.close() ## close all open rgl devices
+  while (length(rgl::rgl.dev.list()) > 0) rgl::close3d() ## close all open rgl devices
   makerglsphere <- function(x, y = NULL, z = NULL, ng = 50, radius = 1, color = "white", add = FALSE, ...) {
     ## code inspired from https://stackoverflow.com/questions/30627647/how-to-plot-a-perfectly-round-sphere-in-r-rgl-spheres
     lat <- matrix(seq(90, -90, len = ng)*pi/180, ng, ng, byrow = TRUE)
@@ -342,11 +343,12 @@ plot.ISOSCAPE <- function(x,
   
   rgl::par3d("windowRect" = c(0, 0, 500, 500))
   rgl::bg3d(sphere = TRUE, color = "darkgrey", lit = FALSE)
-  makerglsphere(0, texture = "IsoriX_world_image.png", lit = FALSE, color = "white") ## alternative to rgl::rgl.spheres()
+  makerglsphere(0, texture = "IsoriX_world_image.png", lit = FALSE, color = "white") ## alternative to rgl::spheres3d()
 }
 
 #' @rdname plots
-#' @export
+#' @method plot ISOFIND
+#' @exportS3Method plot ISOFIND
 plot.ISOFIND <- function(x,
                         who     = "group",
                         cutoff  = list(draw = TRUE, level = 0.05, col = "#909090"),
@@ -358,7 +360,7 @@ plot.ISOFIND <- function(x,
                         mask2   = list(mask = NA, lwd = 0, col = "purple", fill = "purple"),
                         palette = list(step = NA, range = c(0, 1), n_labels = 11, digits = 2, fn = NA),
                         plot    = TRUE,
-                        sphere  = list(build = FALSE, keep_image = FALSE),
+                        sphere  = list(build = FALSE, keep_image = TRUE),
                         ... ## we cannot remove the dots because of the S3 export...
                         ) {
   
@@ -380,20 +382,16 @@ plot.ISOFIND <- function(x,
 
   ## importing country borders if missing
   if (!is.null(borders$borders) && is.na(borders$borders)) {
-    CountryBorders <- NULL
-    utils::data("CountryBorders", envir = environment(), package = "IsoriX")
-    borders$borders <- CountryBorders
+    borders$borders <- terra::readRDS(system.file("extdata/CountryBorders.rds", package = "IsoriX"))
   }
-
+  
   ## importing ocean if missing
-  if (!is.null(mask$mask) && !inherits(mask$mask, "SpatialPolygons") && is.na(mask$mask)) {
-    OceanMask <- NULL
-    utils::data("OceanMask", envir = environment(), package = "IsoriX")
-    mask$mask <- OceanMask
+  if (!is.null(mask$mask) && !inherits(mask$mask, "SpatVector") && is.na(mask$mask)) {
+    mask$mask <- terra::readRDS(system.file("extdata/OceanMask.rds", package = "IsoriX"))
   }
 
   ## changing missing setting for mask2
-  if (!is.null(mask2$mask) && !inherits(mask2$mask, "SpatialPolygons") && is.na(mask2$mask)) {
+  if (!is.null(mask2$mask) && !inherits(mask2$mask, "SpatVector") && is.na(mask2$mask)) {
     mask2$mask <- NULL
   }
 
@@ -442,9 +440,8 @@ plot.ISOFIND <- function(x,
                               n_labels   = palette$n_labels,
                               digits     = palette$digits)
 
-    
-    stack_noNAs <- raster::reclassify(x$sample[[what]][[who]], cbind(NA, NA, 0))
-    if (!identical(raster::values(stack_noNAs), raster::values(x$sample[[what]][[who]]))) {
+     stack_noNAs <- terra::classify(x$sample[[what]][[who]], cbind(NA, NA, 0))
+    if (!identical(terra::values(stack_noNAs), terra::values(x$sample[[what]][[who]]))) {
       warning("The p-values for an assignment samples containing only missing values are considered as 0.")
     }
     
@@ -500,14 +497,17 @@ plot.ISOFIND <- function(x,
 
   ## build the 3D-Sphere
   if (sphere$build) {
-    if (raster::nlayers(stack_noNAs) > 1) {
+    if (terra::nlyr(stack_noNAs) > 1) {
       message("You requested a sphere but you requested several assignment maps.
 In this case, only the first assignment will be drawn on a sphere.
 If you want to build several spheres, build them one by one and do request a single assignment each time.")
     }
     .build_sphere(stack_noNAs[[1]], colours = colours, decor = decor)
     if (!sphere$keep_image) {
-      file.remove("IsoriX_world_image.png")
+      message(paste("IsoriX no longer delete the image used to build the sphere since it prevents rgl to work on some system. \n",
+                    "You can always delete manually the file created which is stored here: \n",
+                    normalizePath(file.path("IsoriX_world_image.png"))))
+      #file.remove("IsoriX_world_image.png")
     }
   }
 
@@ -591,7 +591,8 @@ If you want to build several spheres, build them one by one and do request a sin
 }
 
 #' @rdname plots
-#' @export
+#' @method plot ISOFIT
+#' @exportS3Method plot ISOFIT
 plot.ISOFIT <- function(x, cex_scale = 0.2, ...) {
 
   if (!inherits(x, "ISOFIT")) {
@@ -711,7 +712,8 @@ plot.ISOFIT <- function(x, cex_scale = 0.2, ...) {
 
 
 #' @rdname plots
-#' @export
+#' @method  plot CALIBFIT
+#' @exportS3Method plot CALIBFIT
 plot.CALIBFIT <- function(x,
                           pch = 1,
                           col = "black",
@@ -731,7 +733,8 @@ plot.CALIBFIT <- function(x,
 
 
 #' @rdname plots
-#' @export
+#' @method points CALIBFIT
+#' @exportS3Method points CALIBFIT
 points.CALIBFIT <- function(x,
                             pch = 2,
                             col = "red",
@@ -847,8 +850,9 @@ plotting_calibfit <- function(x, pch, col, line, CI, xlab, ylab, xlim = NULL, yl
 
 
 #' @rdname plots
-#' @export
-plot.RasterLayer <- function(x, ...) {
+#' @method plot SpatRaster
+#' @exportS3Method plot SpatRaster
+plot.SpatRaster <- function(x, ...) {
   print(rasterVis::levelplot(x, margin = FALSE, ...))
   return(invisible(NULL))
 }
@@ -862,15 +866,15 @@ plot.RasterLayer <- function(x, ...) {
   if (!sources$draw) {
     sources_layer <- latticeExtra::layer()
   } else {
-    sources_layer <- latticeExtra::layer(sp::sp.points(sources,
-                                                       col = pt$col,
-                                                       cex = pt$cex,
-                                                       pch = pt$pch,
-                                                       lwd = pt$lwd
+    sources_layer <- latticeExtra::layer(lpoints.SpatVector(sources,
+                                                            col = pt$col,
+                                                            cex = pt$cex,
+                                                            pch = pt$pch,
+                                                            lwd = pt$lwd
     ),
     data = list(sources = x$sp_points$sources,
                 pt = sources,
-                sp.points = sp::sp.points
+                lpoints.SpatVector = lpoints.SpatVector ## TODO: figure out how to pass generic instead of method
     )
     )
   }
@@ -882,15 +886,15 @@ plot.RasterLayer <- function(x, ...) {
     if (!calibs$draw) {
       calibs_layer <- latticeExtra::layer()
     } else {
-      calibs_layer <- latticeExtra::layer(sp::sp.points(calibs,
-                                                        col = pt$col,
-                                                        cex = pt$cex,
-                                                        pch = pt$pch,
-                                                        lwd = pt$lwd
+      calibs_layer <- latticeExtra::layer(lpoints.SpatVector(calibs,
+                                                             col = pt$col,
+                                                             cex = pt$cex,
+                                                             pch = pt$pch,
+                                                             lwd = pt$lwd
       ),
       data = list(calibs = x$sp_points$calibs,
                   pt = calibs,
-                  sp.points = sp::sp.points
+                  lpoints.SpatVector = lpoints.SpatVector ## TODO: figure out how to pass generic instead of method
       )
       )
     }
@@ -903,15 +907,15 @@ plot.RasterLayer <- function(x, ...) {
     if (!assigns$draw) {
       assigns_layer <- latticeExtra::layer()
     } else {
-      assigns_layer <- latticeExtra::layer(sp::sp.points(assigns,
-                                                        col = pt$col,
-                                                        cex = pt$cex,
-                                                        pch = pt$pch,
-                                                        lwd = pt$lwd
+      assigns_layer <- latticeExtra::layer(lpoints.SpatVector(assigns,
+                                                              col = pt$col,
+                                                              cex = pt$cex,
+                                                              pch = pt$pch,
+                                                              lwd = pt$lwd
       ),
       data = list(assigns = x$sp_points$assigns,
                   pt = assigns,
-                  sp.points = sp::sp.points
+                  lpoints.SpatVector = lpoints.SpatVector ## TODO: figure out how to pass generic instead of method
       )
       )
     }
@@ -921,13 +925,12 @@ plot.RasterLayer <- function(x, ...) {
   if (is.null(borders$borders)) {
     borders_layer <- latticeExtra::layer()
   }  else {
-    borders_layer <- latticeExtra::layer(sp::sp.polygons(b$borders,
-                                                         lwd = b$lwd,
-                                                         col = b$col,
-                                                         fill = "transparent"
+    borders_layer <- latticeExtra::layer(lpolygon.SpatVector(b$borders,
+                                                             lwd = b$lwd,
+                                                             border = b$col
     ),
     data = list(b = borders,
-                sp.polygons = sp::sp.polygons
+                lpolygon.SpatVector = lpolygon.SpatVector ## TODO: figure out how to pass generic instead of method
     )
     )
   }
@@ -936,13 +939,13 @@ plot.RasterLayer <- function(x, ...) {
   if (is.null(mask$mask)) {
     mask_layer <- latticeExtra::layer()
   } else {
-    mask_layer <- latticeExtra::layer(sp::sp.polygons(m$mask,
-                                                      fill = m$fill,
-                                                      col = m$col,
-                                                      lwd = m$lwd
+    mask_layer <- latticeExtra::layer(lpolygon.SpatVector(m$mask,
+                                                          col = m$fill,
+                                                          border = m$col,
+                                                          lwd = m$lwd
     ),
     data = list(m = mask,
-                sp.polygons = sp::sp.polygons
+                lpolygon.SpatVector = lpolygon.SpatVector ## TODO: figure out how to pass generic instead of method
     )
     )
   }
@@ -950,13 +953,13 @@ plot.RasterLayer <- function(x, ...) {
   if (is.null(mask2$mask)) {
     mask2_layer <- latticeExtra::layer()
   } else {
-    mask2_layer <- latticeExtra::layer(sp::sp.polygons(m$mask,
-                                                       fill = m$fill,
-                                                       col = m$col,
-                                                       lwd = m$lwd
+    mask2_layer <- latticeExtra::layer(lpolygon.SpatVector(m$mask,
+                                                           col = m$fill,
+                                                           border = m$col,
+                                                           lwd = m$lwd
     ),
     data = list(m = mask2,
-                sp.polygons = sp::sp.polygons
+                lpolygon.SpatVector = lpolygon.SpatVector ## TODO: figure out how to pass generic instead of method
     )
     )
   }
