@@ -20,9 +20,9 @@
 #' below). An aggregation factor of zero (or one) keeps the resolution constant
 #' (default).
 #'
-#' This function relies on calls to the functions [raster::aggregate] and
-#' [raster::crop] from the package \pkg{raster}. It thus share the limitations
-#' of these functions. In particular, [raster::crop] expects extents with
+#' This function relies on calls to the functions [terra::aggregate] and
+#' [terra::crop] from the package \pkg{terra}. It thus share the limitations
+#' of these functions. In particular, [terra::crop] expects extents with
 #' increasing longitudes and latitudes. We have tried to partially relax this
 #' constrains for longitude and you can use the argument \code{manual_crop} to
 #' provide longitudes in decreasing order, which is useful to centre a isoscape
@@ -32,7 +32,7 @@
 #' priorities for now (let us know if you really need this feature).
 #' 
 #' @inheritParams getelev
-#' @param raster The structural raster (*RasterLayer*)
+#' @param raster The structural raster (*SpatRaster*)
 #' @param isofit The fitted isoscape model returned by the function [isofit]
 #' @param aggregation_factor The number of neighbouring cells (*integer*) to
 #'   merge during aggregation
@@ -48,7 +48,7 @@
 #'   of the procedure should be displayed or not while the function is running.
 #'   By default verbose is `TRUE` if users use an interactive R session, and
 #'   `FALSE` otherwise.
-#' @return The prepared structural raster of class *RasterLayer*
+#' @return The prepared structural raster of class *SpatRaster*
 #' @note Aggregating the raster may lead to different results for the
 #'   assignment, because the values of raster cells changes depending on the
 #'   aggregation function (see example below), which in turn affects model
@@ -93,24 +93,23 @@
 #'     margin_pct = 10,
 #'     aggregation_factor = 5, aggregation_fn = max)
 #' 
-#' ## We build the plots of the outcome of the 3 different aggregation schemes
-#' PlotAggregation1 <- levelplot(ElevationRaster1,
-#'         margin = FALSE, main = "Original small raster") + 
-#'     layer(sp.polygons(CountryBorders)) +
-#'     layer(sp.polygons(OceanMask, fill = "blue"))
-#' PlotAggregation2 <- levelplot(ElevationRaster2,
-#'         margin = FALSE, main = "Small raster aggregated (by mean)") + 
-#'     layer(sp.polygons(CountryBorders)) +
-#'     layer(sp.polygons(OceanMask, fill = "blue"))
-#' PlotAggregation3 <- levelplot(ElevationRaster3,
-#'         margin = FALSE, main = "Small raster aggregated (by max)") + 
-#'     layer(sp.polygons(CountryBorders)) +
-#'     layer(sp.polygons(OceanMask, fill = "blue"))  
+#' ## We plot the outcome of the 3 different aggregation schemes using terra
 #' 
-#' ## We plot as a panel using lattice syntax:
-#' print(PlotAggregation1, split = c(1, 1, 3, 1), more = TRUE)
-#' print(PlotAggregation2, split = c(2, 1, 3, 1), more = TRUE)
-#' print(PlotAggregation3, split = c(3, 1, 3, 1))
+#' oripar <- par(mfrow = c(1, 3)) ## display 3 plots side-by-side
+#' 
+#' plot(ElevationRaster1, main = "Original small raster")
+#' polys(CountryBorders)
+#' polys(OceanMask, col = "blue")
+#' 
+#' plot(ElevationRaster2, main = "Small raster aggregated (by mean)")
+#' polys(CountryBorders)
+#' polys(OceanMask, col = "blue")
+#' 
+#' plot(ElevationRaster3, main = "Small raster aggregated (by max)")
+#' polys(CountryBorders)
+#' polys(OceanMask, col = "blue")
+#' 
+#' par(oripar) ## restore graphical settings
 #' }
 #' 
 #' ## The examples below will only be run if sufficient time is allowed
@@ -123,18 +122,18 @@
 #' ### Let's create a raster centered around the pacific
 #' 
 #' ## We first create an empty raster
-#' EmptyRaster <- raster(matrix(0, ncol = 360, nrow = 180))
-#' extent(EmptyRaster) <- c(-180, 180, -90, 90)
-#' projection(EmptyRaster) <- CRS("+proj=longlat +datum=WGS84")
+#' EmptyRaster <- rast(matrix(0, ncol = 360, nrow = 180))
+#' ext(EmptyRaster) <- c(-180, 180, -90, 90)
+#' crs(EmptyRaster) <- "+proj=longlat +datum=WGS84"
 #' 
 #' ## We crop it around the pacific
 #' PacificA <- prepraster(EmptyRaster, manual_crop = c(110, -70, -90, 90))
-#' extent(PacificA) # note that the extent has changed!
+#' ext(PacificA) # note that the extent has changed!
 #' 
 #' ## We plot (note the use of the function shift()!)
-#' levelplot(PacificA, margin = FALSE, colorkey = FALSE) +
-#'   layer(sp.polygons(CountryBorders, fill = "black")) +
-#'   layer(sp.polygons(shift(CountryBorders, dx = 360), fill = "black"))
+#' plot(PacificA, col = "blue", legend = FALSE)
+#' polys(CountryBorders, col = "black")
+#' polys(shift(CountryBorders, dx = 360), col = "black")
 #' 
 #' }
 #' 
@@ -147,21 +146,21 @@ prepraster <- function(raster,
                        manual_crop = NULL,
                        values_to_zero = c(-Inf, 0),
                        verbose = interactive()
-                       ) {
-
+) {
+  
   time <- system.time({
     if (!is.null(isofit)) {  ## test if cropping is needed
       if (inherits(isofit, "multiisofit")) {
         isofit <- isofit$multi.fits[[1]]
-        }
+      }
       if (!is.null(manual_crop)) stop("cannot crop both according to sources and manually! Make up your choice.")
       if (## test if the raster is not smaller than the area covered by the sources.
-          ## If yes crop will not proceed!
-          raster::xmin(raster) > min(isofit$mean_fit$data$long) |
-          raster::xmax(raster) < max(isofit$mean_fit$data$long) |
-          raster::ymin(raster) > min(isofit$mean_fit$data$lat) |
-          raster::ymax(raster) < max(isofit$mean_fit$data$lat)
-          ) {
+        ## If yes crop will not proceed!
+        terra::xmin(raster) > min(isofit$mean_fit$data$long) |
+        terra::xmax(raster) < max(isofit$mean_fit$data$long) |
+        terra::ymin(raster) > min(isofit$mean_fit$data$lat) |
+        terra::ymax(raster) < max(isofit$mean_fit$data$lat)
+      ) {
         warning("the cropping may not make sense (sources located outside structural raster)")
       }
       if (length(values_to_zero) != 2) stop("the argument 'values_to_zero' must contain two values, use 'values_to_zero = c(0, 0)' if you want to prevent the transformation of any value to 0.")
@@ -180,22 +179,22 @@ prepraster <- function(raster,
       if (length(manual_crop) == 4) {
         
         if ((manual_crop[1] > manual_crop[2]) && (manual_crop[3] < manual_crop[4])) {
-          crop1 <- raster::crop(raster,
-                                raster::extent(raster::xmin(raster::extent(raster)),
-                                               manual_crop[2],
-                                               manual_crop[3],
-                                               manual_crop[4]))
-          crop2 <- raster::crop(raster,
-                                raster::extent(manual_crop[1],
-                                               raster::xmax(raster::extent(raster)),
-                                               manual_crop[3],
-                                               manual_crop[4]))
-          raster <- raster::shift(raster::merge(crop1, raster::shift(crop2,
-                                                                     dx = -360)),
-                                  dx = 360)
+          crop1 <- terra::crop(raster,
+                               terra::ext(terra::xmin(terra::ext(raster)),
+                                          manual_crop[2],
+                                          manual_crop[3],
+                                          manual_crop[4]))
+          crop2 <- terra::crop(raster,
+                               terra::ext(manual_crop[1],
+                                          terra::xmax(terra::ext(raster)),
+                                          manual_crop[3],
+                                          manual_crop[4]))
+          raster <- terra::shift(terra::merge(crop1, terra::shift(crop2,
+                                                                  dx = -360)),
+                                 dx = 360)
           warning("The first longitude is greater than the second one. You may want this to study something around the pacific. This feature is not fully supported... but... the function prepraster() tried to cope with this. That implies a change in the coordinate system (0:360 instead of -180:180). This should create no problem for ploting isoscapes but this can create troubles to add polygons or points on the maps. If that is the case, you need to add 360 degree to the longitudes... If all that sounds complicated, just stick to a first longitude SMALLER than the second one.")
         } else {
-          raster <- raster::crop(raster, manual_crop)
+          raster <- terra::crop(raster, manual_crop)
         }
       }
     }
@@ -203,25 +202,25 @@ prepraster <- function(raster,
       if (interactive()) {
         print(paste("aggregating..."))
       }
-      raster <- raster::aggregate(raster, fact = aggregation_factor, fun = aggregation_fn)  ## aggregation
+      raster <- terra::aggregate(raster, fact = aggregation_factor, fun = aggregation_fn)  ## aggregation
     }
   })
-
+  
   ## applies values_to_zero transformation
-  raster::values(raster) <- ifelse(raster::values(raster) < max(values_to_zero) & raster::values(raster) > min(values_to_zero), 0, raster::values(raster))
-
+  terra::values(raster) <- ifelse(terra::values(raster) < max(values_to_zero) & terra::values(raster) > min(values_to_zero), 0, terra::values(raster))
+  
   ## store the raster in memory if possible
-  if (raster::canProcessInMemory(raster)) {
-    raster_HD <- raster
-    raster <- raster::raster(raster_HD)
-    raster::values(raster) <- raster::values(raster_HD)
-  }
+  
+  raster_HD <- raster
+  raster <- terra::rast(raster_HD)
+  terra::values(raster) <- terra::values(raster_HD)
+  
   
   if (verbose) {
     print(paste("done!"))
     print(time)
   }
-
+  
   print(raster)
   return(raster)
 }
