@@ -28,44 +28,6 @@ lattice::xyplot
 #' @export
 latticeExtra::layer
 
-
-
-# reexport from raster:
-
-#' @importFrom raster area
-#' @export
-raster::area
-
-#' @importFrom raster extent
-#' @export
-raster::extent
-
-#' @importFrom raster "extent<-"
-#' @export
-raster::`extent<-`
-
-#' @importFrom raster extract
-#' @export
-raster::extract
-
-#' @importFrom raster "projection<-"
-#' @export
-raster::`projection<-`
-
-#' @importFrom raster raster
-#' @export
-raster::raster
-
-#' @importFrom raster shift
-#' @export
-raster::shift
-
-#' @importFrom raster values
-#' @export
-raster::values
-
-
-
 # reexport from rasterVis:
 
 #' @importFrom rasterVis levelplot
@@ -76,26 +38,55 @@ rasterVis::levelplot
 #' @export
 rasterVis::RdBuTheme
 
-
-
-# reexport from sp:
-
-#' @importFrom sp CRS
-#' @export
-sp::CRS
-
-#' @importFrom sp sp.points
-#' @export
-sp::sp.points
-
-#' @importFrom sp sp.polygons
-#' @export
-sp::sp.polygons
-
-
-
 # reexport from spaMM:
 
 #' @importFrom spaMM get_ranPars
 #' @export
 spaMM::get_ranPars
+
+
+# reexport from terra:
+
+#' @importFrom terra plot
+#' @export
+terra::plot
+
+#' @importFrom terra points
+#' @export
+terra::points
+
+#' @importFrom terra polys
+#' @export
+terra::polys
+
+#' @importFrom terra rast
+#' @export
+terra::rast
+
+#' @importFrom terra crs
+#' @export
+terra::crs
+
+#' @importFrom terra "crs<-"
+#' @export
+terra::"crs<-"
+
+#' @importFrom terra ext
+#' @export
+terra::ext
+
+#' @importFrom terra "ext<-"
+#' @export
+terra::"ext<-"
+
+#' @importFrom terra shift
+#' @export
+terra::shift
+
+#' @importFrom terra values
+#' @export
+terra::values
+
+#' @importFrom terra cellSize
+#' @export
+terra::cellSize
\ No newline at end of file
